from importlib.metadata import PackageNotFoundError, version

from ._inflate64 import Inflater  # noqa

__all__ = Inflater

__doc__ = """\
Python library to inflate data, the API is similar to Python's bz2/lzma/zlib module.
"""

__copyright__ = "Copyright (C) 2022 Hiroshi Miura"

try:
    __version__ = version(__name__)
except PackageNotFoundError:  # pragma: no-cover
    # package is not installed
    __version__ = "0.1.0"



import os
import pathlib
import zipfile

import pytest

import inflate64
from inflate64 import dev

testdata_path = pathlib.Path(os.path.dirname(__file__)).joinpath("data")
srcdata = testdata_path.joinpath("src.zip")


@pytest.mark.skip(reason="Implementation is not completed.")
@pytest.mark.parametrize("fname,minsize,maxsize", [("test-file.1", 3000, 3600), ("test-file.2", 3100, 3700)])
def test_compress(fname, minsize, maxsize):
    with zipfile.ZipFile(srcdata) as f:
        data = f.read(fname)
    compressor = dev.Deflater()
    compressed = compressor.deflate(data)
    compressed += compressor.flush()
    #
    decompressor = inflate64.Inflater()
    extracted = decompressor.inflate(compressed)
    assert len(extracted) == len(data)



#!/usr/bin/env python3
import os
import sys

from setuptools import Extension, setup
from setuptools.command.build_ext import build_ext
from setuptools.command.egg_info import egg_info


sources = [
    "src/lib/deflate.c",
    "src/lib/deflate_tree.c",
    "src/lib/inflate.c",
    "src/lib/inflate_tree.c",
    "src/lib/util.c"
]
packages = ["inflate64"]
kwargs = {"include_dirs": ["src/lib", "src/ext"], "library_dirs": [], "libraries": [], "sources": sources, "define_macros": []}
# binary extension
kwargs["name"] = "inflate64._inflate64"
kwargs["sources"].append("src/ext/_inflate64module.c")
binary_extension = Extension(**kwargs)
_deflate64_extension = Extension("inflate64._inflate64", sources)


def has_option(option):
    if option in sys.argv:
        sys.argv = [s for s in sys.argv if s != option]
        return True
    else:
        return False


WARNING_AS_ERROR = has_option("--warning-as-error")
DEBUG_BUILD = has_option("--debug")


class build_ext_compiler_check(build_ext):
    def build_extensions(self):
        for extension in self.extensions:
            if self.compiler.compiler_type.lower() in ("unix", "mingw32"):
                if WARNING_AS_ERROR:
                    extension.extra_compile_args.append("-Werror")
                if DEBUG_BUILD:
                    extension.extra_compile_args.extend(["-DZLIB_DEBUG"])
            elif self.compiler.compiler_type.lower() == "msvc":
                # /GF eliminates duplicate strings
                # /Gy does function level linking
                more_options = ["/GF", "/Gy"]
                if WARNING_AS_ERROR:
                    more_options.append("/WX")
                extension.extra_compile_args.extend(more_options)
        super().build_extensions()


# Work around pypa/setuptools#436.
class my_egg_info(egg_info):
    def run(self):
        try:
            os.remove(os.path.join(self.egg_info, "SOURCES.txt"))
        except FileNotFoundError:
            pass
        super().run()


setup(
    ext_modules=[binary_extension],
    package_dir={"": "src"},
    packages=packages,
    cmdclass={"build_ext": build_ext_compiler_check, "egg_info": my_egg_info},
)



import os
import pathlib
import zipfile

import pytest

import inflate64

testdata_path = pathlib.Path(os.path.dirname(__file__)).joinpath("data")
testdata = testdata_path.joinpath("test-file.zip")
srcdata = testdata_path.joinpath("src.zip")


@pytest.mark.parametrize(
    "fname,offset,length",
    [
        ("test-file.1", 41, 3096),
        ("test-file.2", 36434, 3112),
        ("test-file.3", 42984, 3125),
        ("test-file.4", 46150, 3143),
        ("test-file.5", 49334, 3156),
        ("test-file.6", 52531, 3169),
        ("test-file.7", 55741, 3186),
        ("test-file.8", 58968, 3198),
        ("test-file.9", 62207, 3210),
        ("test-file.10", 3179, 3227),
        ("test-file.11", 6448, 3237),
        ("test-file.12", 9727, 3249),
        ("test-file.13", 13018, 3266),
        ("test-file.14", 16326, 3277),
        ("test-file.15", 19645, 3289),
        ("test-file.16", 22976, 3304),
        ("test-file.17", 26322, 3316),
        ("test-file.18", 29680, 3328),
        ("test-file.19", 33050, 3343),
        ("test-file.20", 39588, 3355),
    ],
)
def test_decompress(tmp_path, fname, offset, length):
    with testdata.open("rb") as f:
        _ = f.seek(offset, os.SEEK_SET)
        data = f.read(length)
    with zipfile.ZipFile(srcdata) as z:
        expected = z.read(fname)
    decompressor = inflate64.Inflater()
    result = decompressor.inflate(data)
    assert len(result) == len(expected)
    assert result == expected
